==> mvvirtualdevice-x86-ABI2-1.10.49.127.tgz: mvimpact_acquire-x86-1.10.49.127/apps/mvPropView/ImageCanvas.h <==
//-----------------------------------------------------------------------------
#ifndef imageCanvasH
#define imageCanvasH imageCanvasH
//-----------------------------------------------------------------------------
#include "DrawingCanvas.h"
#include <set>
#include <vector>
#include <wx/bitmap.h>
#include <wx/brush.h>
#include <wx/colour.h>
#include <wx/dcclient.h>
#include <wx/image.h>

typedef std::set<AOI*> AOISet;

struct ImageCanvasImpl;

//-----------------------------------------------------------------------------
class ImageCanvas : public DrawingCanvas
//-----------------------------------------------------------------------------
{
public:
	ImageCanvas() {}
	ImageCanvas( wxWindow* pApp, wxWindow* parent, wxWindowID id = -1, const wxPoint& pos = wxDefaultPosition, const wxSize& size = wxDefaultSize,
				 long style = wxSUNKEN_BORDER, const wxString& name = wxT("ImageCanvas"), bool boActive = true );
	~ImageCanvas();
	void									OnKeyDown( wxKeyEvent& e );
	void									OnPaint( wxPaintEvent& e );
	bool									IsScaled( void ) const { return m_boScaleToClientSize; }
	bool									OverlayMessagesActive( void ) const { return m_boShowOverlayMessages; }
	bool									InfoOverlayActive( void ) const { return m_boShowInfoOverlay; }
	void									RefreshScrollbars( void );
	AOI*									RegisterAOI( const wxRect&, const wxColour&, const wxString& );
	bool									RemoveAOI( AOI* pAOI );
	//-----------------------------------------------------------------------------
	enum TSaveResult
	//-----------------------------------------------------------------------------
	{
		srOK,
		srNoImage,
		srFailedToSave
	};
	void									IncreaseSkippedCounter( unsigned long count );
	TSaveResult								SaveCurrentImage( const wxString& filenameAndPath, const wxString& extension ) const;
	bool									SetAOI( AOI* pAOI, int x, int y, int w, int h );
	bool									SetImage( const mvIMPACT::acquire::ImageBuffer* pIB );
	void									SetScaling( bool boOn );
	void									SetInfoOverlay( const std::vector<wxString>& infoStrings );
	void									SetInfoOverlayMode( bool boOn );
	void									SetPerformanceWarningOutput( bool boOn );
private:
	enum
	{
		PERFORMANCE_WARNINGS_Y_OFFSET = 20,
		SKIPPED_IMAGE_MESSAGE_Y_OFFSET = 40,
		INFO_Y_OFFSET = 60
	};
	ImageCanvasImpl*						m_pImpl;
	AOISet									m_aoiSet;
	bool									m_boScaleToClientSize;
	bool									m_boShowInfoOverlay;
	std::vector<wxString>					m_infoStringsOverlay;
	bool									m_boShowOverlayMessages;
	wxEvtHandler*							m_pAppEventHandler;
	int										m_pAppWinID;
	unsigned long							m_skippedImages;
	const mvIMPACT::acquire::ImageBuffer*	m_pIB;
	double									m_currentZoomFactor;
	double									m_zoomFactor_Max;
	void									BlitAOIs( wxPaintDC& dc, double scaleFactor, int bmpXOff, int bmpYOff, int bmpW, int bmpH );
	void									BlitInfoStrings( wxPaintDC& dc, double scaleFactor, int bmpXOff, int bmpYOff, int bmpW, int bmpH );
	void									BlitPerformanceMessages( wxPaintDC& dc, int bmpXOff, int bmpYOff, TImageBufferPixelFormat pixelFormat );
	void									DeleteAOIs( void );
	void									Init( const wxWindow* const pApp );
	void									SetMaxZoomFactor( const mvIMPACT::acquire::ImageBuffer* pIB, int oldMaxDim );
	TSaveResult								StoreImage( const wxImage& img, const wxString& filenameAndPath, const wxString& extension ) const;
	DECLARE_DYNAMIC_CLASS(ImageCanvas)
	DECLARE_EVENT_TABLE()
	void									OnDblClick( wxMouseEvent& );
};

#endif // imageCanvasH

==> mvvirtualdevice-x86-ABI2-1.10.99.177.tgz: mvimpact_acquire-x86-1.10.99.177/apps/mvPropView/ImageCanvas.h <==
//-----------------------------------------------------------------------------
#ifndef imageCanvasH
#define imageCanvasH imageCanvasH
//-----------------------------------------------------------------------------
#include "DrawingCanvas.h"
#include <map>
#include <vector>
#include <wx/bitmap.h>
#include <wx/brush.h>
#include <wx/colour.h>
#include <wx/dcclient.h>
#include <wx/image.h>

typedef std::map<const DrawingCanvas*, AOI*> AOIContainer;

struct ImageCanvasImpl;

//-----------------------------------------------------------------------------
class ImageCanvas : public DrawingCanvas
//-----------------------------------------------------------------------------
{
public:
	ImageCanvas() {}
	ImageCanvas( wxWindow* pApp, wxWindow* parent, wxWindowID id = -1, const wxPoint& pos = wxDefaultPosition, const wxSize& size = wxDefaultSize,
				 long style = wxSUNKEN_BORDER, const wxString& name = wxT("ImageCanvas"), bool boActive = true );
	~ImageCanvas();
	wxRect									GetVisiblePartOfImage( void );
	bool									IsScaled( void ) const { return m_boScaleToClientSize; }
	bool									OverlayMessagesActive( void ) const { return m_boShowOverlayMessages; }
	bool									InfoOverlayActive( void ) const { return m_boShowInfoOverlay; }
	void									RefreshScrollbars( bool boMoveToMousePos = false );
	AOI*									RegisterAOI( const wxRect&, const wxColour&, const DrawingCanvas* const pOwner );
	bool									RegisterMonitorDisplay( ImageCanvas* pMonitorDisplay );
	bool									RemoveAOI( const DrawingCanvas* const pOwner );
	//-----------------------------------------------------------------------------
	enum TSaveResult
	//-----------------------------------------------------------------------------
	{
		srOK,
		srNoImage,
		srFailedToSave
	};
	void									IncreaseSkippedCounter( size_t count );
	void									HandleMouseAndKeyboardEvents( bool boHandle );
	TSaveResult								SaveCurrentImage( const wxString& filenameAndPath, const wxString& extension ) const;
	void									SetActiveAnalysisPlot( const ImageAnalysisPlotCanvas* pPlot );
	const ImageAnalysisPlotCanvas*			GetActiveAnalysisPlot( void ) const { return m_pActiveAnalysisPlot; }
	bool									SetAOI( const ImageAnalysisPlotCanvas* pPlot, int x, int y, int w, int h );
	bool									SetImage( const mvIMPACT::acquire::ImageBuffer* pIB );
	void									SetScaling( bool boOn );
	void									SetInfoOverlay( const std::vector<wxString>& infoStrings );
	void									SetInfoOverlayMode( bool boOn );
	void									SetPerformanceWarningOutput( bool boOn );
	void									GetCurrentPixel( double* pScale, wxPoint* pPoint );
private:
	//-----------------------------------------------------------------------------
	enum
	//-----------------------------------------------------------------------------
	{
		PERFORMANCE_WARNINGS_Y_OFFSET = 20,
		SKIPPED_IMAGE_MESSAGE_Y_OFFSET = 40,
		INFO_Y_OFFSET = 60
	};
	//-----------------------------------------------------------------------------
	enum TZoomIncrementMode
	//-----------------------------------------------------------------------------
	{
		zimMultiply,
		zimDivide
	};
	ImageCanvasImpl*						m_pImpl;
	AOIContainer							m_aoiContainer;
	bool									m_boHandleMouseAndKeyboardEvents;
	const ImageAnalysisPlotCanvas*			m_pActiveAnalysisPlot;
	bool									m_boScaleToClientSize;
	bool									m_boShowInfoOverlay;
	std::vector<wxString>					m_infoStringsOverlay;
	bool									m_boShowOverlayMessages;
	wxEvtHandler*							m_pAppEventHandler;
	int										m_pAppWinID;
	size_t									m_skippedImages;
	const mvIMPACT::acquire::ImageBuffer*	m_pIB;
	double									m_currentZoomFactor;
	double									m_zoomFactor_Max;
	wxPoint									m_lastLeftMouseDownPos;
	wxPoint									m_lastRightMouseDownPos;
	AOI										m_AOIAtLeftMouseDown;
	AOI										m_AOIAtRightMouseDown;
	bool									m_boAOIDragInProgress;
	wxPoint									m_lastMousePos;
	wxPoint									m_lastStartPoint;
	double									m_lastScaleFactor;
	ImageCanvas*							m_pMonitorDisplay;
	AOI*									m_pVisiblePartOfImage;
	void									BlitAOIs( wxPaintDC& dc, double scaleFactor, int bmpXOff, int bmpYOff, int bmpW, int bmpH );
	void									BlitInfoStrings( wxPaintDC& dc, double scaleFactor, int bmpScaledViewXOff, int bmpScaledViewVOff, int bmpXOff, int bmpYOff, int bmpW, int bmpH );
	void									BlitPerformanceMessages( wxPaintDC& dc, int bmpXOff, int bmpYOff, TImageBufferPixelFormat pixelFormat );
	void									ClipAOI( wxRect& rect, bool boForDragging ) const;
	void									DeleteAOIs( void );
	void									Init( const wxWindow* const pApp );
	void									SetMaxZoomFactor( const mvIMPACT::acquire::ImageBuffer* pIB, int oldMaxDim );
	TSaveResult								StoreImage( const wxImage& img, const wxString& filenameAndPath, const wxString& extension ) const;
	void									UpdateZoomFactor( TZoomIncrementMode zim, double value );
	DECLARE_DYNAMIC_CLASS(ImageCanvas)
	DECLARE_EVENT_TABLE()
	void									OnKeyDown( wxKeyEvent& e );
	void									OnLeftDblClick( wxMouseEvent& );
	void									OnLeftDown( wxMouseEvent& );
	void									OnMotion( wxMouseEvent& );
	void									OnMouseWheel( wxMouseEvent& );
	void									OnPaint( wxPaintEvent& e );
	void									OnRightDown( wxMouseEvent& );
};

#endif // imageCanvasH
